#!/bin/sh
glilang=

echo
if [ "$glilang" == "ru" ]; then
    echo "-- Still coming --"
else
    echo 'Greenstone Librarian Interface (GLI)'
    echo 'Copyright (C) 2004, New Zealand Digital Library Project, University Of Waikato'
    echo 'GLI comes with ABSOLUTELY NO WARRANTY; for details see LICENSE.txt'
    echo 'This is free software, and you are welcome to redistribute it'
fi
echo

##  -------- Run the Greenstone Librarian Interface --------

# This script must be run from within the directory in which it lives
thisdir=`pwd`
if [ ! -f "${thisdir}/gli.sh" ]; then
    if [ "$glilang" == "ru" ]; then
	echo "      ,    "
    else
	echo "This script must be run from the directory in which it resides."
    fi
    exit 1
fi


##  ---- Determine GSDLHOME ----
gsdlpath=

# Some users may set the above line manually
if [ "$gsdlpath" == "" ]; then
    # Check the environment variable first
    if [ "$GSDLHOME" != "" ]; then
	gsdlpath=$GSDLHOME

    # If it is not set, assume that the GLI is installed as a subdirectory of Greenstone
    else
	pushd .. > /dev/null
	gsdlpath=`pwd`
	popd > /dev/null
    fi
fi

# Check that the Greenstone installation looks OK
if [ "$glilang" == "ru" ]; then
    echo " GSDL: $gsdlpath"
else
    echo "Checking GSDL: $gsdlpath"
fi
if [ ! -f "${gsdlpath}/setup.bash" ] ; then
    echo
    if [ "$glilang" == "ru" ]; then
	echo " Greenstone      ."
	echo "   Greenstone,      ."
    else
	echo "The Greenstone installation could not be found, or is incomplete."
	echo "Try reinstalling Greenstone then running this script again."
    fi
    exit 1
fi

# Setup Greenstone, unless it has already been done
if [ "$GSDLHOME" == "" ]; then
    pushd $gsdlpath > /dev/null
    source setup.bash
    popd > /dev/null
fi


##  ---- Check Perl exists ----
perlpath=

# Some users may set the above line manually
if [ "$perlpath" == "" ]; then
    # Check if Perl is on the search path
    perlpath=`which perl 2> /dev/null`
fi

# Check that a Perl executable has been found
if [ "$glilang" == "ru" ]; then
    echo " Perl: $perlpath"
else
    echo "Checking Perl: $perlpath"
fi
if [ ! -x "$perlpath" ] ; then
    echo
    if [ "$glilang" == "ru" ]; then
	echo "  Greenstone  Perl,   "
	echo ",  Perl     . , ,  "
	echo "Perl       ,  "
	echo " ."
    else
	echo "The Greenstone Librarian Interface requires perl in order to operate,"
	echo "but perl could not be detected on your system. Please ensure that perl"
	echo "is installed and is on your search path, then rerun this script."
    fi
    exit 1
fi


## ---- Check Java exists ----
javapath=

# Some users may set the above line manually
if [ "$javapath" == "" ]; then

    # If it is set, use the JAVA_HOME environment variable
    if [ "$JAVA_HOME" != "" ]; then
	javapath="$JAVA_HOME/bin/java"

    # Check if Java is on the search path
    else
	javapath=`which java 2> /dev/null`
    fi
fi

# Check that a Java executable has been found
if [ "$glilang" == "ru" ]; then
    echo " Java: $javapath"
else
    echo "Checking Java: $javapath"
fi
if [ ! -x "$javapath" ]; then
    echo
    if [ "$glilang" == "ru" ]; then
	echo "      Java."
	echo "   Java Runtime Environment ( 1.4  )"
	echo "    Greenstone."
    else
	echo "Failed to locate an appropriate version of Java. You must install a"
	echo "Java Runtime Environment (version 1.4 or greater) before running the"
	echo "Greenstone Librarian Interface."
    fi
    exit 1
fi


## -- Check the version of Java is new enough (1.4.0 or higher) to run the GLI --
javaversion=`$javapath -version 2>&1 | sed -n 's/^java version \"\(.*\)\"/\1/p'`
jvmajor=`echo $javaversion | sed -n 's/^\([0-9]*\).*$/\1/p'`
jvminor=`echo $javaversion | sed -n 's/^[0-9]*\.\([0-9]*\).*$/\1/p'`

jok=1
if [ $jvmajor -lt 1 ] ; then
    jok=0
fi
if [ $jvmajor -eq 1 ] && [ $jvminor -lt 4 ] ; then
    jok=0
fi
if [ $jok -eq 0 ] ; then
    echo
    if [ "$glilang" == "ru" ]; then
	echo " Java Runtime Environment,   ,  ,"
	echo "    Greenstone. , "
	echo "   JRE ( 1.4   ) "
	echo "  "
    else
	echo "The version of the Java Runtime Environment you have installed is too"
	echo "old to run the Greenstone Librarian Interface. Please install a new"
	echo "version of the JRE (version 1.4 or newer) and rerun this script."
    fi
    exit 1
fi

## ---- Check that the GLI has been compiled ----
if [ ! -f "classes/org/greenstone/gatherer/Gatherer.class" ] && [ ! -f "GLI.jar" ]; then
    echo
    if [ "$glilang" == "ru" ]; then
	echo "     Greenstone"
	echo "( makegli.sh)    "
    else
	echo "You need to compile the Greenstone Librarian Interface (using makegli.sh)"
	echo "before running this script."
    fi
    exit 1
fi

if [ "$1" == "-test" ]; then
    if [ "$glilang" == "ru" ]; then
	echo "-- Still coming --"
    else
	echo "Testing class: $2"
	echo "arguments $*"
    fi
    java -classpath classes/:GLI.jar:lib/apache.jar:lib/calpa.jar:lib/jp.jar:lib/polloxml.jar:lib/qfslib.jar:lib/skinlf.jar $2 $3
    exit 0
fi

## ---- Finally, run the GLI ----
echo
if [ "$glilang" == "ru" ]; then
    echo "   Greenstone..."
else
    echo "Running the Greenstone Librarian Interface..."
fi

# Other arguments you can provide to GLI to work around memory limitations, or debug
# -Xms<number>M    To set minimum memory (by default 32MB)
# -Xmx<number>M    To set maximum memory (by default the nearest 2^n to the total remaining physical memory)
# -verbose:gc      To set garbage collection messages
# -Xincgc          For incremental garbage collection (significantly slows performance)
# -Xprof           Function call profiling
# -Xloggc:<file>   Write garbage collection log

java -classpath classes/:GLI.jar:lib/apache.jar:lib/calpa.jar:lib/jp.jar:lib/polloxml.jar:lib/qfslib.jar:lib/skinlf.jar org.greenstone.gatherer.Gatherer -gsdl $GSDLHOME -wget $wok$wgetpath $*

if [ "$glilang" == "ru" ]; then
    echo "!"
else
    echo "Done!"
fi